pub struct RoomPrivacySettings<'a> { /* private fields */ }Expand description
A helper to group the methods in Room related to the room’s visibility and access.
Implementations
Sourceimpl<'a> RoomPrivacySettings<'a>
impl<'a> RoomPrivacySettings<'a>
Sourcepub async fn publish_room_alias_in_room_directory(
&'a self,
alias: &RoomAliasId,
) -> Result<bool>
pub async fn publish_room_alias_in_room_directory( &'a self, alias: &RoomAliasId, ) -> Result<bool>
Publish a new room alias for this room in the room directory.
Returns:
trueif the room alias didn’t exist and it’s now published.falseif the room alias was already present so it couldn’t be published.
Sourcepub async fn remove_room_alias_from_room_directory(
&'a self,
alias: &RoomAliasId,
) -> Result<bool>
pub async fn remove_room_alias_from_room_directory( &'a self, alias: &RoomAliasId, ) -> Result<bool>
Remove an existing room alias for this room in the room directory.
Returns:
trueif the room alias was present and it’s now removed from the room directory.falseif the room alias didn’t exist so it couldn’t be removed.
Sourcepub async fn update_canonical_alias(
&'a self,
alias: Option<OwnedRoomAliasId>,
alt_aliases: Vec<OwnedRoomAliasId>,
) -> Result<()>
pub async fn update_canonical_alias( &'a self, alias: Option<OwnedRoomAliasId>, alt_aliases: Vec<OwnedRoomAliasId>, ) -> Result<()>
Update the canonical alias of the room.
Arguments
alias- The new main alias to use for the room. ANonevalue removes the existing main canonical alias.alt_aliases- The list of alternative aliases for this room.
See the specification for more info about the canonical alias.
Note that publishing the alias in the room directory is done separately, and a room alias must have already been published before it can be set as the canonical alias.
Sourcepub async fn update_room_history_visibility(
&'a self,
new_value: HistoryVisibility,
) -> Result<()>
pub async fn update_room_history_visibility( &'a self, new_value: HistoryVisibility, ) -> Result<()>
Update room history visibility for this room.
The history visibility controls whether a user can see the events that happened in a room before they joined.
See the specification for more info.
Sourcepub async fn update_join_rule(&'a self, new_rule: JoinRule) -> Result<()>
pub async fn update_join_rule(&'a self, new_rule: JoinRule) -> Result<()>
Update the join rule for this room.
The join rules controls if and how a new user can get access to the room.
See the specification for more info.
Sourcepub async fn update_room_retention(
&'a self,
content: RoomRetentionEventContent,
) -> Result<()>
pub async fn update_room_retention( &'a self, content: RoomRetentionEventContent, ) -> Result<()>
Update the message retention policy for this room.
The caller must have a power level sufficient to send the
m.room.retention state event (typically power level 50). The server
will reject the request if the power level is insufficient.
The content must satisfy max_lifetime >= min_lifetime; use
RoomRetentionEventContent’s builder methods to construct a valid
value.
See MSC1763 for more info.
Sourcepub async fn get_room_visibility(&'a self) -> Result<Visibility>
pub async fn get_room_visibility(&'a self) -> Result<Visibility>
Returns the visibility for this room in the room directory.
Public rooms are listed in the room directory and can be found using it.
Sourcepub async fn update_room_visibility(
&'a self,
visibility: Visibility,
) -> Result<()>
pub async fn update_room_visibility( &'a self, visibility: Visibility, ) -> Result<()>
Update the visibility for this room in the room directory.
Public rooms are listed in the room directory and can be found using it.